@@ -24,7 +24,6 @@
 #'
 #' @keywords utilities
 #'
-#' @import sp
 #' @import rgdal
 #'
 #' @export
@@ -33,15 +32,15 @@
 #' library(raster)
 #'
 #' coords <- rbind(c(-100, -90), c(80, 90), c(80, 0), c(40, -40))
-#' crs <- CRS("+init=epsg:4326")
-#' transect <- SpatialPoints(coords, proj4string = crs)
+#' crs <- sp::CRS("+init=epsg:4326")
+#' transect <- sp::SpatialPoints(coords, proj4string = crs)
 #' r <- raster(nrows = 10, ncols = 10, ymn = -80, ymx = 80, crs = crs)
 #' names(r) <- "value"
 #' set.seed(0)
 #' r[] <- runif(ncell(r))
 #' r[4, 6] <- NA
 #' plot(r, xlab = "x", ylab = "y")
-#' lines(SpatialLines(list(Lines(list(Line(coords)), ID = "Transect")), proj4string = crs))
+#' lines(SpatialLines(list(sp::Lines(list(sp::Line(coords)), ID = "Transect")), proj4string = crs))
 #' points(transect, pch = 21, bg = "red")
 #' segs <- ExtractAlongTransect(transect, r)
 #' for (i in 1:length(segs)) points(segs[[i]], col = "blue")
@@ -55,7 +54,7 @@
 #' plot(NA, type = "n", xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim)
 #' for (i in 1:length(segs))
 #'   lines(segs[[i]]@data[, c("dist", "value")], col = rainbow(length(segs))[i])
-#' coords <- coordinates(transect)
+#' coords <- sp::coordinates(transect)
 #' n <- length(transect)
 #' d <- cumsum(c(0, as.matrix(dist((coords)))[cbind(1:(n - 1), 2:n)]))
 #' abline(v = d, col = "grey", lty = 2)
@@ -73,18 +72,18 @@ ExtractAlongTransect <- function(transect, r) {
   if (inherits(transect, "SpatialLines"))
     transect <- methods::as(transect, "SpatialPoints")
 
-  crs <- CRS(proj4string(r))
+  crs <- sp::CRS(proj4string(r))
 
-  v <- coordinates(spTransform(transect, crs))
+  v <- sp::coordinates(sp::spTransform(transect, crs))
   if (length(v) < 2) stop("number of vertices in transect is < 2")
 
-  r.xmin <- xmin(r)
-  r.xmax <- xmax(r)
-  r.ymin <- ymin(r)
-  r.ymax <- ymax(r)
+  r.xmin <- raster::xmin(r)
+  r.xmax <- raster::xmax(r)
+  r.ymin <- raster::ymin(r)
+  r.ymax <- raster::ymax(r)
 
-  rx <- seq(r.xmin, r.xmax, by=xres(r))
-  ry <- seq(r.ymin, r.ymax, by=yres(r))
+  rx <- seq(r.xmin, r.xmax, by=raster::xres(r))
+  ry <- seq(r.ymin, r.ymax, by=raster::yres(r))
 
   dist.along.transect <- as.matrix(stats::dist(v))
   segs <- list()
@@ -122,12 +121,12 @@ ExtractAlongTransect <- function(transect, r) {
     d <- c(d[1], rep(d[2:(n - 1L)], each=2), d[n])
 
     n <- length(x)
-    seg <- cbind(x, y, dist=d, matrix(NA, nrow=n, ncol=nlayers(r),
+    seg <- cbind(x, y, dist=d, matrix(NA, nrow=n, ncol=raster::nlayers(r),
                  dimnames=list(NULL, names(r))))
     colnames(seg) <- make.names(colnames(seg), unique=TRUE)
 
-    for (j in seq_len(nlayers(r))) {
-      z <- extract(r[[j]], SpatialPoints(cbind(mid.x, mid.y)))
+    for (j in seq_len(raster::nlayers(r))) {
+      z <- raster::extract(r[[j]], sp::SpatialPoints(cbind(mid.x, mid.y)))
       seg[, j + 3L] <- rep(z, each=2)
     }
     rownames(seg) <- NULL
@@ -151,9 +150,8 @@ ExtractAlongTransect <- function(transect, r) {
     v.d <- c(v.d, dist.along.transect[i, i + 1L])
   }
 
-  FUN <- function(s) {
-    SpatialPointsDataFrame(s[, 1:2], data.frame(s[, -(1:2)], row.names=NULL),
-                           proj4string=crs, match.ID=FALSE)
-  }
-  return(lapply(segs, FUN))
+  return(lapply(segs, function(s) {
+    sp::SpatialPointsDataFrame(s[, 1:2], data.frame(s[, -(1:2)], row.names=NULL),
+                               proj4string=crs, match.ID=FALSE)
+  }))
 }
