@@ -64,9 +64,7 @@
 #'
 #' @keywords hplot
 #'
-#' @import sp
 #' @import rgdal
-#' @import raster
 #'
 #' @export
 #'
@@ -122,10 +120,10 @@ PlotCrossSection <- function(transect, rs, geo.lays=names(rs), val.lays=NULL,
   if (length(val.lays) >= length(geo.lays))
     stop("number of value layers is greater than the number of geometry layers")
 
-  transect <- spTransform(transect, crs(rs))
-  rs <- crop(rs, extent(as.vector(t(bbox(transect)))), snap="out")
+  transect <- sp::spTransform(transect, raster::crs(rs))
+  rs <- raster::crop(rs, raster::extent(as.vector(t(bbox(transect)))), snap="out")
   layer.names <- unique(c(geo.lays, val.lays, wt.lay))
-  eat <- ExtractAlongTransect(transect, subset(rs, layer.names))
+  eat <- ExtractAlongTransect(transect, raster::subset(rs, layer.names))
 
   cell.values <- NULL
   cell.polys  <- list()
@@ -139,7 +137,7 @@ PlotCrossSection <- function(transect, rs, geo.lays=names(rs), val.lays=NULL,
                    seg[k, c("dist", geo.lays[i]), drop=FALSE])
         if (anyNA(p)) next
         cell.values <- c(cell.values, v)
-        cell.polys  <- c(cell.polys, Polygon(p))
+        cell.polys  <- c(cell.polys, sp::Polygon(p))
       }
     }
   }
@@ -172,15 +170,14 @@ PlotCrossSection <- function(transect, rs, geo.lays=names(rs), val.lays=NULL,
     }
     cols <- unique(cell.cols)
 
-    FUN <- function(i) {
-      p <- Polygons(cell.polys[which(cell.cols == cols[i])], i)
-      p <- rgeos::gUnaryUnion(SpatialPolygons(list(p), i))
+    p <- lapply(seq_along(cols), function(i) {
+      p <- sp::Polygons(cell.polys[which(cell.cols == cols[i])], i)
+      p <- rgeos::gUnaryUnion(sp::SpatialPolygons(list(p), i))
       p <- methods::slot(p, "polygons")[[1]]
       p@ID <- cols[i]
       return(p)
-    }
-    p <- lapply(seq_along(cols), FUN)
-    cell.polys.merged <- SpatialPolygons(p, seq_along(cols))
+    })
+    cell.polys.merged <- sp::SpatialPolygons(p, seq_along(cols))
   }
 
   x <- unlist(lapply(eat, function(i) i@data$dist))
@@ -199,8 +196,8 @@ PlotCrossSection <- function(transect, rs, geo.lays=names(rs), val.lays=NULL,
   mai2 <- c(0.6, 4.6, 4, 2) * csi
   if (draw.key) {
     y1 <- csi
-    FUN <- function(i) {if (is.null(i)) 0 else length(strsplit(i, "\n")[[1]])}
     mai1 <- c(1.2, 4.6, NA, 2) * csi
+    FUN <- function(i) {if (is.null(i)) 0 else length(strsplit(i, "\n")[[1]])}
     mai1[3] <- FUN(explanation) * (csi * 0.7)
   } else {
     y1 <- 0
@@ -256,8 +253,8 @@ PlotCrossSection <- function(transect, rs, geo.lays=names(rs), val.lays=NULL,
 
   # plot map
   graphics::par(mai=mai2, mgp=c(3, 0.7, 0))
-  plot(NA, type="n", xlim=xlim, ylim=ylim, xaxs="i", yaxs="i", bty="n",
-       xaxt="n", yaxt="n", xlab="", ylab="", asp=asp)
+  graphics::plot(NA, type="n", xlim=xlim, ylim=ylim, xaxs="i", yaxs="i", bty="n",
+                 xaxt="n", yaxt="n", xlab="", ylab="", asp=asp)
   usr <- graphics::par("usr")
 
   if (is.null(file)) {
@@ -266,37 +263,37 @@ PlotCrossSection <- function(transect, rs, geo.lays=names(rs), val.lays=NULL,
   }
 
   if (is.character(bg.col)) {
-    FUN <- function(i) {
+    bg.poly <- sp::SpatialPolygons(list(sp::Polygons(lapply(eat, function(i) {
       m <- cbind(x=i@data[[1]], y=i@data[[2]])
       m <- rbind(m, cbind(rev(range(m[, "x"], na.rm=TRUE)), usr[3]), m[1, , drop=FALSE])
-      return(Polygon(m))
-    }
-    bg.poly <- SpatialPolygons(list(Polygons(lapply(eat, FUN), "bg")), 1L)
-    plot(bg.poly, col=bg.col, border=NA, lwd=0.1, add=TRUE)
+      return(sp::Polygon(m))
+    }), "bg")), 1L)
+    sp::plot(bg.poly, col=bg.col, border=NA, lwd=0.1, add=TRUE)
   }
 
-  plot(cell.polys.merged, col=cols, border=cols, lwd=0.1, add=TRUE)
+  sp::plot(cell.polys.merged, col=cols, border=cols, lwd=0.1, add=TRUE)
 
   if (!is.null(wt.lay) && wt.lay[1] %in% names(rs)) {
     for (s in eat)
-      lines(s@data[["dist"]], s@data[, wt.lay[1]], lwd=lwd, col=wt.col)
+      graphics::lines(s@data[["dist"]], s@data[, wt.lay[1]], lwd=lwd, col=wt.col)
   }
 
-  lays <- if (draw.sep) geo.lays else c(head(geo.lays, 1), tail(geo.lays, 1))
+  lays <- if (draw.sep) geo.lays else c(utils::head(geo.lays, 1), utils::tail(geo.lays, 1))
   for (s in eat)
     graphics::matplot(s@data[["dist"]], s@data[, lays], xaxt="n", yaxt="n",
                       type="l", lty=1, lwd=lwd, col="#1F1F1F", add=TRUE)
 
   if (is.list(contour.lines)) {
-    e <- extent(cell.polys.merged)
+    e <- raster::extent(cell.polys.merged)
     nc <- 200
     dx <- diff(e[1:2]) / nc
     nr <- as.integer(diff(e[3:4]) / (dx / asp))
-    r <- raster(e, nrows=nr, ncols=nc)
-    FUN <- function(i) Polygons(list(cell.polys[[i]]), as.character(i))
-    p <- lapply(seq_along(cell.polys), FUN)
-    p <- SpatialPolygons(p, seq_along(cell.polys))
-    r <- rasterize(p, r)
+    r <- raster::raster(e, nrows=nr, ncols=nc)
+    p <- lapply(seq_along(cell.polys), function(i) {
+      sp::Polygons(list(cell.polys[[i]]), as.character(i))
+    })
+    p <- sp::SpatialPolygons(p, seq_along(cell.polys))
+    r <- raster::rasterize(p, r)
     r[] <- cell.values[r[]]
 
     color <- as.character(contour.lines[["col"]])
@@ -341,25 +338,25 @@ PlotCrossSection <- function(transect, rs, geo.lays=names(rs), val.lays=NULL,
   y <- unlist(lapply(eat, function(i) i@data[[geo.lays[1]]]))
   GetGeoTop <- stats::approxfun(x, y)
   pady <- diff(usr[3:4]) * 0.02
-  d <- as.matrix(stats::dist(coordinates(methods::as(transect, "SpatialPoints"))))[, 1]
-  dist.to.bend <- head(d[-1], -1)
+  d <- as.matrix(stats::dist(sp::coordinates(methods::as(transect, "SpatialPoints"))))[, 1]
+  dist.to.bend <- utils::head(d[-1], -1)
   for (d in dist.to.bend) {
     y <- GetGeoTop(d)
-    lines(c(d, d), c(usr[3], y + pady), lwd=0.3, col="#999999")
-    text(d, y + pady, "BEND", adj=c(-0.1, 0.5), col="#999999", cex=0.6, srt=90)
+    graphics::lines(c(d, d), c(usr[3], y + pady), lwd=0.3, col="#999999")
+    graphics::text(d, y + pady, "BEND", adj=c(-0.1, 0.5), col="#999999", cex=0.6, srt=90)
   }
   if (!is.null(features)) {
     tran.pts <- do.call("rbind", eat)
     for (i in seq_len(length(features))) {
-      pnt <- spTransform(features, crs(rs))[i, ]
+      pnt <- sp::spTransform(features, raster::crs(rs))[i, ]
       dist.to.transect <- rgeos::gDistance(pnt, tran.pts, byid=TRUE)
       idx <- which.min(dist.to.transect)
       if (dist.to.transect[idx] > max.feature.dist) next
       d <- x[idx]
       y <- GetGeoTop(d)
-      lines(c(d, d), c(y, y + pady), lwd=0.3)
+      graphics::lines(c(d, d), c(y, y + pady), lwd=0.3)
       label <- format(pnt@data[1, 1])
-      text(d, y + pady, label, adj=c(-0.1, 0.5), cex=cex, srt=90)
+      graphics::text(d, y + pady, label, adj=c(-0.1, 0.5), cex=cex, srt=90)
     }
   }
   graphics::par(xpd=FALSE)
