@@ -48,6 +48,9 @@
 #'   located at \href{https://github.com/twitter/AnomalyDetection}{twitter/AnomalyDetection}.
 #' @param quiet 'logical'.
 #'   If true, reduce the amount of output.
+#' @param parallel 'logical' or 'integer'.
+#'   Whether to use parallel processes for a parallel install of more than one source package.
+#'   This argument can also be used to specify the number of cores to employ.
 #' @param pkg 'character'.
 #'   One or more names of packages located under \code{lib}.
 #'   Only packages specified in \code{pkg}, and the packages that \code{pkg} depend on/link to/import/suggest,
@@ -110,11 +113,6 @@
 #'   \pkg{checkpoint} and \pkg{packrat} packages;
 #'   both of which provide robust tools for dependency management in \R.
 #'
-#'   If affiliated with the U.S. Department of Interior (DOI), you may receive the following error message:
-#'   \dQuote{SSL certificate problem: unable to get local issuer certificate}.
-#'   The error results from a missing X.509 certificate that permits the DOI to scan encrypted data for security reasons.
-#'   A fix for this error is given in the \code{\link{AddCertificate}} function documentation.
-#'
 #' @author J.C. Fisher, U.S. Geological Survey, Idaho Water Science Center
 #'
 #' @seealso \code{\link[utils]{installed.packages}}, \code{\link[utils]{install.packages}}
@@ -134,7 +132,7 @@
 #' }
 #'
 #' # Clean up example
-#' unlink("R-packages.tsv")
+#' file.remove("R-packages.tsv")
 #'
 #' @rdname RecreateLibrary
 #' @export
@@ -142,7 +140,13 @@
 RecreateLibrary <- function(file="R-packages.tsv", lib=.libPaths()[1],
                             repos=getOption("repos"), snapshot=FALSE,
                             local=NULL, versions=FALSE, github=FALSE,
-                            quiet=FALSE) {
+                            parallel=TRUE, quiet=FALSE) {
+
+  checkmate::qassert(parallel, c("B1", "X1[0,)"))
+
+  # set number of parallel process
+  if (is.logical(parallel))
+    parallel <- if (parallel) max(1L, parallel::detectCores() - 1L) else 1L
 
   # set environment variable for certificates path
   if (.Platform$OS.type == "windows" && Sys.getenv("CURL_CA_BUNDLE") == "") {
@@ -223,7 +227,7 @@ RecreateLibrary <- function(file="R-packages.tsv", lib=.libPaths()[1],
                             stringsAsFactors=FALSE)
 
   # filter out packages that are already installed
-  pkgs <- pkgs[!.IsPackageInstalled(pkgs$Package, lib), , drop=FALSE]
+  pkgs <- pkgs[!IsPackageInstalled(pkgs$Package, lib), , drop=FALSE]
   if (nrow(pkgs) == 0) return(invisible(NULL))
 
   # install packages from local files
@@ -258,10 +262,10 @@ RecreateLibrary <- function(file="R-packages.tsv", lib=.libPaths()[1],
       path <- path[!duplicated(nam) & nam %in% pkgs$Package]
     }
     if (length(path) > 0) {
-      utils::install.packages(path, lib[1], repos=NULL, quiet=quiet)
+      utils::install.packages(path, lib[1], repos=NULL, Ncpus=parallel, quiet=quiet)
 
       # filter out packages that were installed from local files
-      pkgs <- pkgs[!.IsPackageInstalled(pkgs$Package, lib), , drop=FALSE]
+      pkgs <- pkgs[!IsPackageInstalled(pkgs$Package, lib), , drop=FALSE]
       if (nrow(pkgs) == 0) return(invisible(NULL))
     }
   }
@@ -275,9 +279,11 @@ RecreateLibrary <- function(file="R-packages.tsv", lib=.libPaths()[1],
   if (any(is_on_repos)) {
     if (versions && requireNamespace("devtools", quietly=TRUE)) {
       for (i in which(is_on_repos)) {
-        if (.IsPackageInstalled(pkgs$Package[i], lib)) next
-        ans <- try(devtools::install_version(pkgs$Package[i], pkgs$Version[i],
-                                             type=type, quiet=quiet), silent=TRUE)
+        if (IsPackageInstalled(pkgs$Package[i], lib)) next
+        ans <- try({
+          devtools::install_version(pkgs$Package[i], pkgs$Version[i],
+                                    type=type, quiet=quiet)
+        }, silent=TRUE)
         if (inherits(ans, "try-error")) {
           is_on_repos[i] <- FALSE
           next
@@ -285,17 +291,17 @@ RecreateLibrary <- function(file="R-packages.tsv", lib=.libPaths()[1],
       }
     } else {
       utils::install.packages(pkgs$Package[is_on_repos], lib[1], repos=repos,
-                              type=type, quiet=quiet)
+                              type=type, Ncpus=parallel, quiet=quiet)
     }
   }
 
   # install packages from github
   if (any(!is_on_repos) && github && requireNamespace("githubinstall", quietly=TRUE))
     githubinstall::gh_install_packages(pkgs$Package[!is_on_repos],
-                                       quiet=quiet, lib=lib[1])
+                                       quiet=quiet, lib=lib[1], threads=parallel)
 
   # warn about packages that could not be installed
-  if (any(is <- !.IsPackageInstalled(pkgs$Package, lib))) {
+  if (any(is <- !IsPackageInstalled(pkgs$Package, lib))) {
     msg <- sprintf("The following packages could not be installed:\n %s\n",
                    paste(pkgs$Package[is], collapse=", "))
     warning(msg, call.=FALSE)
@@ -325,7 +331,7 @@ SavePackageDetails <- function(file="R-packages.tsv", lib=.libPaths(), pkg=NULL)
                      paste(pkg[is], collapse=", "))
       stop(msg, call.=FALSE)
     }
-    FUN <- function(i) {
+    p <- c(unlist(lapply(pkg, function(i) {
       x <- utils::packageDescription(i, lib)
       x <- c(x$Depends, x$LinkingTo, x$Imports, x$Suggests)
       if (is.null(x)) return(NULL)
@@ -334,8 +340,7 @@ SavePackageDetails <- function(file="R-packages.tsv", lib=.libPaths(), pkg=NULL)
       x <- gsub("\\s*\\([^\\)]+\\)", "", x)
       x <- strsplit(x, ", ")[[1]]
       return(x)
-    }
-    p <- c(unlist(lapply(pkg, FUN)), pkg)
+    })), pkg)
     pkgs <- pkgs[pkgs[, "Package"] %in% p, , drop=FALSE]
   }
 
@@ -375,79 +380,30 @@ SavePackageDetails <- function(file="R-packages.tsv", lib=.libPaths(), pkg=NULL)
   invisible(md5)
 }
 
+
 #' Check whether Package is Installed
 #'
+#' This function checks whether a package(s) is installed under the library tree(s).
+#'
 #' @param x 'character'.
 #'   Vector of package names
 #' @param lib 'character'.
-#'   Vector of library tree(s)
+#'   Vector of library trees
 #'
-#' @return A 'logical' vector the length of \code{x}.
-#'
-
-.IsPackageInstalled <- function(x, lib) {
-  FUN <- function(i) {system.file(package=i, lib.loc=lib) != ""}
-  return(vapply(x, FUN, TRUE))
-}
-
-#' Add X.509 Certificate
-#'
-#' This function adds a \href{https://en.wikipedia.org/wiki/X.509}{X.509} certificate
-#' to your bundle of certificate authority root certificates (CA bundle).
-#' The X.509 certificate is used to authenticate clients and servers.
-#' And the CA bundle is a file that contains root and intermediate certificates.
-#'
-#' @param file 'character'.
-#'   Path (or a complete URL) to the file containing the X.509 certificate.
-#' @param header 'character'.
-#'   Header line to identify the certificate (optional).
-#'
-#' @note This function must be used on Windows and requires access to the \pkg{httr} package.
+#' @return A 'logical' vector the length of argument \code{x}.
 #'
 #' @author J.C. Fisher, U.S. Geological Survey, Idaho Water Science Center
 #'
-#' @seealso \code{\link{RecreateLibrary}}
-#'
 #' @keywords internal
 #'
 #' @export
 #'
 #' @examples
-#' # Install the U.S. Department of Interior (DOI) certificate (employees only):
-#' \dontrun{
-#' AddCertificate(file = "http://sslhelp.doi.net/docs/DOIRootCA2.cer",
-#'                header = "DOI Root CA 2")
-#' }
+#' IsPackageInstalled(c("inlmisc", "csimlni", "colorspace"))
 #'
 
-AddCertificate <- function(file, header=NULL) {
-
-  checkmate::assertOS("windows")
-  checkmate::assertCharacter(header, len=1, any.missing=FALSE, null.ok=TRUE)
-
-  if (!requireNamespace("httr", quietly=TRUE))
-    stop("Requires access to the 'httr' package.", call.=FALSE)
-
-  if (!file.exists(file) & httr::http_error(file))
-    stop("Certificate file doesn't exist or access is denied.", call.=FALSE)
-
-  certificate <- readLines(file)
-
-  bundle <- Sys.getenv("CURL_CA_BUNDLE")
-  if (bundle == "")
-    bundle <- system.file("cacert.pem", package="openssl", mustWork=TRUE)
-  if (!file.exists(bundle))
-    stop("Can't locate CA bundle file.", call.=FALSE)
-
-  if (all(certificate %in% readLines(bundle))) {
-    message("Certificate has already been added to CA bundle.")
-  } else {
-    if (!is.null(header))
-      header <- c(header, paste(rep("=", nchar(header)), collapse=""))
-    certificate <- c("", header, certificate)
-    cat(certificate, file=bundle, sep="\n", append=TRUE)
-    message("Certificate added to CA bundle:\n ", normalizePath(bundle))
-  }
-
-  invisible(NULL)
+IsPackageInstalled <- function(x, lib=.libPaths()) {
+  return(vapply(x, function(i) {
+    system.file(package=i, lib.loc=lib) != ""
+  }, TRUE))
 }
